.. _recipe_asr.raman:

asr.raman
=========


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.raman`-recipe.
This recipe is comprised of a single step, namely:

  - :py:func:`asr.raman.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.raman

or as a python module

.. code-block:: console

   $ python -m asr.raman

Detailed description
--------------------
Raman spectrum.

Steps
-----


asr.raman
^^^^^^^^^
.. autofunction:: asr.raman.main
   